@@ -147,6 +147,21 @@ class AllegroGraphServer(object):
         """Return the server's version as a string."""
         return self._client.getVersion()
 
+    @property
+    def versionTuple(self):
+        """
+        Return the version number as a tuple of integers.
+
+        All non-digit characters from the version string are ignored
+        and act only as separators. All trailing zeros are skipped.
+        This is compatible with the way in which the Java client
+        parses and compares AG version strings.
+        """
+        components = [int(c) for c in re.findall(r'\d+', self.version)]
+        while components and components[-1] == 0:
+            components.pop()
+        return tuple(components)
+
     def listCatalogs(self):
         """
         Get the list of catalogs on this server.
@@ -179,7 +194,7 @@ class AllegroGraphServer(object):
             raise ServerException("There is no catalog named '%s' (found %s)"
                 % (name, cats))
 
-        return Catalog(name, self._client)
+        return Catalog(name, self, self._client)
 
     def getInitfile(self):
         """
@@ -226,7 +241,7 @@ class AllegroGraphServer(object):
         :rtype: RepositoryConnection
         """
         minirep = self._client.openSession(spec, autocommit=autocommit, lifetime=lifetime, loadinitfile=loadinitfile)
-        return RepositoryConnection(Repository(None, None, minirep))
+        return RepositoryConnection(Repository(None, None, minirep), is_session=True)
 
     def listScripts(self):
         """
@@ -269,10 +284,57 @@ class AllegroGraphServer(object):
         """
         return self._client.getScript(module)
 
+    def getUserData(self, key):
+        """
+        Retrieve user data value with given key.
+
+        Users can store arbitrary strings on the server
+        using :meth:`setUserData`.
+
+        :param key: Value identifier.
+        :type key: str
+        :return: Stored string or None if there is no data under specified key.
+        :rtype: str|None
+        """
+        return self._client.getUserData(key)
+
+    def setUserData(self, key, data):
+        """
+        Set user data with given key.
+
+        This can be used to store arbitrary strings on the server.
+
+        :param key: Value identifier.
+        :type key: str
+        :param data: Value to be stored.
+        :type data: str
+        """
+        self._client.setUserData(key, data)
+
+    def deleteUserData(self, key):
+        """
+        Remove user data from the server.
+
+        This removes a value set with :meth:`setUserData`
+
+        :param key: Value identifier.
+        :type key: str
+        """
+        self._client.deleteUserData(key)
+
+    def listUserData(self):
+        """
+        Get all used keys from the user data store on the server.
+
+        :return: A list of key names.
+        :rtype: list[str]
+        """
+        return self._client.listUserData()
+
     def openFederated(self, repositories, autocommit=False, lifetime=None, loadinitfile=False):
         """
         Open a session that federates several repositories. The
-        repositories argument should be an array containing store
+        repositories argument must be an array containing store
         designators, which can be Repository or RepositoryConnection
         objects, strings (naming a store in the root catalog, or the
         URL of a store), or (storename, catalogname) tuples.
@@ -539,7 +601,8 @@ class Catalog(object):
     """
     Container of multiple repositories (triple stores).
     """
-    def __init__(self, name, client):
+    def __init__(self, name, server, client):
+        self.server = server
         self.mini_catalog = client.openCatalogByName(name)
         self._name = name
 
